@@ -1,14 +1,18 @@
 package Data::ModeMerge;
 BEGIN {
-  $Data::ModeMerge::VERSION = '0.25';
+  $Data::ModeMerge::VERSION = '0.27';
 }
 # ABSTRACT: Merge two nested data structures, with merging modes and options
 
 
 use 5.010;
-use Any::Moose;
+use strict;
+use warnings;
+
 use Data::ModeMerge::Config;
 use Data::Dumper;
+use Moo;
+
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(mode_merge);
@@ -370,8 +374,6 @@ sub _path_is_included {
 }
 
 
-__PACKAGE__->meta->make_immutable;
-no Any::Moose;
 1;
 
 __END__
@@ -383,7 +385,7 @@ Data::ModeMerge - Merge two nested data structures, with merging modes and optio
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -789,7 +791,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Steven Haryanto.
+This software is copyright (c) 2011 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
